summaryrefslogtreecommitdiffstats
path: root/opensuse/core/tdelibs/kdelibs-3.5.10-kio.patch
diff options
context:
space:
mode:
authorRobert Xu <robxu9@gmail.com>2012-03-31 14:28:06 -0400
committerRobert Xu <robxu9@gmail.com>2012-03-31 14:28:06 -0400
commit59dd46ef985a719579132efa6a9aa49bfeeae112 (patch)
tree93d8c721ff263e67aaf59e364496862872ded8fb /opensuse/core/tdelibs/kdelibs-3.5.10-kio.patch
parentc141f0bc29b6e2eeda5ca08a043d26546a1427f9 (diff)
downloadtde-packaging-59dd46ef985a719579132efa6a9aa49bfeeae112.tar.gz
tde-packaging-59dd46ef985a719579132efa6a9aa49bfeeae112.zip
better late than never, hm...
Diffstat (limited to 'opensuse/core/tdelibs/kdelibs-3.5.10-kio.patch')
-rw-r--r--opensuse/core/tdelibs/kdelibs-3.5.10-kio.patch21
1 files changed, 6 insertions, 15 deletions
diff --git a/opensuse/core/tdelibs/kdelibs-3.5.10-kio.patch b/opensuse/core/tdelibs/kdelibs-3.5.10-kio.patch
index 9fb299d4a..8cba39f49 100644
--- a/opensuse/core/tdelibs/kdelibs-3.5.10-kio.patch
+++ b/opensuse/core/tdelibs/kdelibs-3.5.10-kio.patch
@@ -4,12 +4,12 @@
return true;
}
-+bool KZip::writeDir(const QString& name, const QString& user, const QString& group)
++bool KZip::writeDir(const TQString& name, const TQString& user, const TQString& group)
+{
+ // Zip files have no explicit directories, they are implicitly created during extraction time
+ // when file entries have paths in them.
+ // However, to support empty directories, we must create a dummy file entry which ends with '/'.
-+ QString dirName = name;
++ TQString dirName = name;
+ if (!name.endsWith("/"))
+ dirName = dirName.append('/');
+
@@ -19,17 +19,8 @@
+}
+
// Doesn't need to be reimplemented anymore. Remove for KDE-4.0
- bool KZip::writeFile( const QString& name, const QString& user, const QString& group, uint size, const char* data )
+ bool KZip::writeFile( const TQString& name, const TQString& user, const TQString& group, uint size, const char* data )
{
-@@ -1114,7 +1128,7 @@
- }
-
- // delete entries in the filelist with the same filename as the one we want
-- // to save, so that we don´t have duplicate file entries when viewing the zip
-+ // to save, so that we don�t have duplicate file entries when viewing the zip
- // with konqi...
- // CAUTION: the old file itself is still in the zip and won't be removed !!!
- QPtrListIterator<KZipFileEntry> it( d->m_fileList );
diff -up kdelibs-3.5.10/kio/kio/kzip.h.orig kdelibs-3.5.10/kio/kio/kzip.h
--- kdelibs-3.5.10/kio/kio/kzip.h.orig 2009-12-09 19:35:42.000000000 +0100
+++ kdelibs-3.5.10/kio/kio/kzip.h 2009-12-09 19:35:48.000000000 +0100
@@ -40,8 +31,8 @@ diff -up kdelibs-3.5.10/kio/kio/kzip.h.orig kdelibs-3.5.10/kio/kio/kzip.h
- /**
- * @internal Not needed for zip
- */
-- virtual bool writeDir( const QString& name, const QString& user, const QString& group) { Q_UNUSED(name); Q_UNUSED(user); Q_UNUSED(group); return true; }
-+ virtual bool writeDir(const QString& name, const QString& user, const QString& group);
+- virtual bool writeDir( const TQString& name, const TQString& user, const TQString& group) { Q_UNUSED(name); Q_UNUSED(user); Q_UNUSED(group); return true; }
++ virtual bool writeDir(const TQString& name, const TQString& user, const TQString& group);
// TODO(BIC) uncomment and make virtual for KDE 4.
// bool writeDir( const QString& name, const QString& user, const QString& group,
// mode_t perm, time_t atime, time_t mtime, time_t ctime );
@@ -40,8 +31,8 @@ diff -up kdelibs-3.5.10/kio/kio/kzip.h.orig kdelibs-3.5.10/kio/kio/kzip.h
// TODO(BIC) uncomment and make virtual for KDE 4.
- // bool writeDir( const QString& name, const QString& user, const QString& group,
+ // bool writeDir( const TQString& name, const TQString& user, const TQString& group,
// mode_t perm, time_t atime, time_t mtime, time_t ctime );